==> zither-1.1.18.tar.gz: zither_prj/sitar/jpreturn.h <==
// 
// Υեjpretun.hˤϡsitar(biwa)Фܸ᤹ʸdefineʬܤƤޤ
// ɬ EUC-JP Υ󥳡ǥ󥰤¸Ƥ
// 
//


#ifndef _JPRETURN_H_
  #define _JPRETURN_H_
  
#define SNMP_1 "OIDʸʤǤ͡  "
#define SNMP_2 "ǥߥ'['οǤ  "
#define SNMP_3 "§黻ҤǤ  "
#define SNMP_4 "ǡϿǤ  "
#define SNMP_5 "ŬڤOIDα黻˽ʤʤʥơ֤Ƥޤ  "
#define SNMP_7 "OID  "
#define SNMP_9 "SNMPƻ롢׻˹Ԥޤ  "
#define SNMP_10 "ȥåפֻäݤǤ͡  "
#define SNMP_11 "ͤĶޤ  "
#define SNMP_12 "ͤĶƤޤ  "
#define SNMP_13 "ְ꤬ͤäƤޤ󤫡  "
#define SNMP_14 "ͤ˿ʳޤޤޤ󤫡  "
#define SNMP_15 "ȥåפֻǤ  "
#define SNMP_19 "Ʊֻ֤Ƥޤ  "
#define SNMP_20 "Ʊ֤ͤƤޤ  "
#define SNMP_21 "Ǥºݤͤ򲼤ƥ顼Ф뤫ǧƤ  "
#define SNMP_22 "ǡϿǤ  "
#define SNMP_23 "ͤԤäƤ  "
#define SNMP_24 "§黻ҰʳȤƤޤ  "
#define SNMP_25 "оݤSNMPDȤΥå˼Ԥޤ  "
#define SNMP_26 "оݤSNMPDȤΥåޤ  "
#define SNMP_27 "OID̤ϿʪǤ  "
#define SNMP_28 "OIDθ˥ޥåΤޤ  "
#define SNMP_29 "оݤSNMPDʥơ֤Ƥޤ  "
#define SNMP_30 "SNMPͤȥ󥰤Ǥ  "

#define SOCK_1 "åȤޤǤ  "
#define SOCK_2 "̾Ѵ˹ԤޤǤ "
#define SOCK_3 "ͥ˳ΩǤޤ  "
#define SOCK_4 "֤᤮Ƥ⥳ͥ󤬳ΩǤޤǤ  "
#define SOCK_5 "ͥ˳ΩǤޤǤ  "
#define SOCK_6 "ƻоݤͥåȥ¸ߤʤǽޤ  "
#define SOCK_7 "ICMPݡãѥåȤޤݡȤϳƤޤ  "
#define SOCK_8 "̾Ѵ˽ޤ  "
#define SOCK_9 "оݤȰۤʤä̾ԤäƤޤ󤫡  "
#define SOCK_10 "̾褬ॢȤޤNSʤǤ "
#define SOCK_11 "̾褬˽ޤ "
#define SOCK_12 "ͽ "
#define SOCK_13 "getsockopt()ˤڥǥ󥰥顼μ˹Ԥʤ "
#define SOCK_14 "ꤵ줿IPۥȤݡֹ椬¸ߤʤǽޤ "
#define SOCK_15 "select() Ԥǥ顼ȯƤޤ "
#define SOCK_16 "ͥ󤬥ॢȤޤ "

#define URL_1 "URL ֤äƤơɤ200ְʳǤ  "
#define URL_2 "URL Υǡ뤳ȤޤǤ  "
#define URL_3 "URL Υǡ줺ॢȤޤ  "
#define URL_4 "URL ֤äƤơɤ200Ǥ "

#define SMTP_1 "SMTP HELOФ֤äƤơɤ200ְʳǤ  "
#define SMTP_11 "SMTP ³Υơɤ200ְʳǤ  "
#define SMTP_2 "SMTP HELOФƤΥǡ뤳ȤޤǤ  "
#define SMTP_22 "SMTP ³μǡǡ򤦤ȤޤǤ "
#define SMTP_3 "SMTP HELOФƤǡ줺ॢȤޤ  "
#define SMTP_33 "SMTP ³Υǡ줺ॢȤޤ  "
#define SMTP_4 "SMTP HELOФ֤äƤơɤ200Ǥ "
#define SMTP_44 "SMTP ³֤äƤơɤ200Ǥ "

#define COM_1 "¹ԥޥɤॢȤޤ  "
#define COM_2 "ޥɤ¹ԤǤޤǤ  "
#define COM_3 "Ǥºݤͤ򲼤ƥ顼Ф뤫ǧƤ "
#define COM_4 "֤ͤƤʤǽޤ "

#define ICMP_1 "RAW socket Ȥˤroot¤ɬפǤ  "
#define ICMP_2 "ICMP ѥåȤ뤳ȤޤǤ  "
#define ICMP_3 " ICMP ѥåȤ뤳Ȥޤ  "
#define ICMP_4 " ICMP ѥåȤäƤޤ  "
#define ICMP_5 "ICMP RTT ͤäƤޤ  "
#define ICMP_6 "ICMP RTT ͤǤ  "
#define ICMP_7 "ICMP ѥåȤŪۥȤãǤޤǤȺǸΥ롼äƤޤ  "
#define ICMP_8 "ICMP ѥåȤTTL0ˤʤꡢѥåȤ˴ޤ"
#define ICMP_13 "ICMPѥåȤ뤳Ȥޤ "

#define MUTEX_1 "Ʊ˼¹Խ֥åοäƤޤ  "


#define X509_1 "ͭ°Ǥ "
#define X509_2 "ͭ¤λڤޤ "
#define X509_3 "ͭ¤λĤ3Ǥ "
#define X509_4 "ͭ¤᤮ޤ "
#define X509_5 "ͭǤ "

#define X509_11 ""
#define X509_12 ""
#define X509_13 ""
#define X509_14 ""

#define HTTPS_1 "SLL X509 Ǥ "
#define HTTPS_2 "SLL X509 ϰ۾֤ƤޤΥǡǤ "


#define MONITOR_ERR_1  "ʤƻ°ꤷƤޤ㤨SNMPȤʤ饤ȤSNMP꤬Ƥޤ  "

#define BLOCK_TEST_1 "ƻ˶ιܤޤޤޤ "
#define BLOCK_TEST_2 "ƻΥǡ礭 "
#define BLOCK_TEST_3 "ƻΥǥߥο "
#define BLOCK_TEST_4 "ƻƬब'#'Ǥ롢̾盧߾֤Ǥ "
#define BLOCK_TEST_5 " "
#define BLOCK_TEST_6 "۾ "
#define BLOCK_TEST_7 "ƻ˲餫꤬褦Ǥ "

#define ERR_MAIL_1 "Ļδְ㤤 "
#define ERR_MAIL_2 "Υ֥å˳Ƥ줿Ļ֤äƤޤ "
#define ERR_MAIL_3 "Ļܤ¿١ιԤĻ뤵Ƥޤ "



#endif

==> zither-1.1.20.tar.gz: zither_prj/sitar/jpreturn.h <==
// 
// Υեjpretun.hˤϡsitar(biwa)Фܸ᤹ʸdefineʬܤƤޤ
// ɬ EUC-JP Υ󥳡ǥ󥰤¸Ƥ
// 
//


#ifndef _JPRETURN_H_
  #define _JPRETURN_H_
  
#define SNMP_1 "OIDʸʤǤ͡  "
#define SNMP_2 "ǥߥ'['οǤ  "
#define SNMP_3 "§黻ҤǤ  "
#define SNMP_4 "ǡϿǤ  "
#define SNMP_5 "ŬڤOIDα黻˽ʤʤʥơ֤Ƥޤ  "
#define SNMP_7 "OID  "
#define SNMP_9 "SNMPƻ롢׻˹Ԥޤ  "
#define SNMP_10 "ȥåפֻäݤǤ͡  "
#define SNMP_11 "ͤĶޤ  "
#define SNMP_12 "ͤĶƤޤ  "
#define SNMP_13 "ְ꤬ͤäƤޤ󤫡  "
#define SNMP_14 "ͤ˿ʳޤޤޤ󤫡  "
#define SNMP_15 "ȥåפֻǤ  "
#define SNMP_19 "Ʊֻ֤Ƥޤ  "
#define SNMP_20 "Ʊ֤ͤƤޤ  "
#define SNMP_21 "Ǥºݤͤ򲼤ƥ顼Ф뤫ǧƤ  "
#define SNMP_22 "ǡϿǤ  "
#define SNMP_23 "ͤԤäƤ  "
#define SNMP_24 "§黻ҰʳȤƤޤ  "
#define SNMP_25 "оݤSNMPDȤΥå˼Ԥޤ  "
#define SNMP_26 "оݤSNMPDȤΥåޤ  "
#define SNMP_27 "OID̤ϿʪǤ  "
#define SNMP_28 "OIDθ˥ޥåΤޤ  "
#define SNMP_29 "оݤSNMPDʥơ֤Ƥޤ  "
#define SNMP_30 "SNMPͤȥ󥰤Ǥ  "
#define SNMP_31 "åȤ̿Ԥʤ  "
#define SNMP_32 "SNMPͤϰǤ "
#define SNMP_33 "SNMPͤϰϳǤ "
#define SNMP_34 "ͤϰϤꤨޤ "

#define SOCK_1 "åȤޤǤ  "
#define SOCK_2 "̾Ѵ˹ԤޤǤ "
#define SOCK_3 "ͥ˳ΩǤޤ  "
#define SOCK_4 "֤᤮Ƥ⥳ͥ󤬳ΩǤޤǤ  "
#define SOCK_5 "ͥ˳ΩǤޤǤ  "
#define SOCK_6 "ƻоݤͥåȥ¸ߤʤǽޤ  "
#define SOCK_7 "ICMPݡãѥåȤޤݡȤϳƤޤ  "
#define SOCK_8 "̾Ѵ˽ޤ  "
#define SOCK_9 "оݤȰۤʤä̾ԤäƤޤ󤫡  "
#define SOCK_10 "̾褬ॢȤޤNSʤǤ "
#define SOCK_11 "̾褬˽ޤ "
#define SOCK_12 "ͽ "
#define SOCK_13 "getsockopt()ˤڥǥ󥰥顼μ˹Ԥʤ "
#define SOCK_14 "ꤵ줿IPۥȤݡֹ椬¸ߤʤǽޤ "
#define SOCK_15 "select() Ԥǥ顼ȯƤޤ "
#define SOCK_16 "ͥ󤬥ॢȤޤ "

#define URL_1 "URL ֤äƤơɤ200ְʳǤ  "
#define URL_2 "URL Υǡ뤳ȤޤǤ  "
#define URL_3 "URL Υǡ줺ॢȤޤ  "
#define URL_4 "URL ֤äƤơɤ200Ǥ "

#define SMTP_1 "SMTP HELOФ֤äƤơɤ200ְʳǤ  "
#define SMTP_11 "SMTP ³Υơɤ200ְʳǤ  "
#define SMTP_2 "SMTP HELOФƤΥǡ뤳ȤޤǤ  "
#define SMTP_22 "SMTP ³μǡǡ򤦤ȤޤǤ "
#define SMTP_3 "SMTP HELOФƤǡ줺ॢȤޤ  "
#define SMTP_33 "SMTP ³Υǡ줺ॢȤޤ  "
#define SMTP_4 "SMTP HELOФ֤äƤơɤ200Ǥ "
#define SMTP_44 "SMTP ³֤äƤơɤ200Ǥ "

#define COM_1 "¹ԥޥɤॢȤޤ  "
#define COM_2 "ޥɤ¹ԤǤޤǤ  "
#define COM_3 "Ǥºݤͤ򲼤ƥ顼Ф뤫ǧƤ "
#define COM_4 "֤ͤƤʤǽޤ "

#define ICMP_1 "RAW socket Ȥˤroot¤ɬפǤ  "
#define ICMP_2 "ICMP ѥåȤ뤳ȤޤǤ  "
#define ICMP_3 " ICMP ѥåȤ뤳Ȥޤ  "
#define ICMP_4 " ICMP ѥåȤäƤޤ  "
#define ICMP_5 "ICMP RTT ͤäƤޤ  "
#define ICMP_6 "ICMP RTT ͤǤ  "
#define ICMP_7 "ICMP ѥåȤŪۥȤãǤޤǤȺǸΥ롼äƤޤ  "
#define ICMP_8 "ICMP ѥåȤTTL0ˤʤꡢѥåȤ˴ޤ"
#define ICMP_13 "ICMPѥåȤ뤳Ȥޤ "

#define MUTEX_1 "Ʊ˼¹Խ֥åοäƤޤ  "


#define X509_1 "ͭ°Ǥ "
#define X509_2 "ͭ¤λڤޤ "
#define X509_3 "ͭ¤λĤ3Ǥ "
#define X509_4 "ͭ¤᤮ޤ "
#define X509_5 "ͭǤ "

#define X509_11 ""
#define X509_12 ""
#define X509_13 ""
#define X509_14 ""

#define HTTPS_1 "SLL X509 Ǥ "
#define HTTPS_2 "SLL X509 ϰ۾֤ƤޤΥǡǤ "


#define MONITOR_ERR_1  "ʤƻ°ꤷƤޤ㤨SNMPȤʤ饤ȤSNMP꤬Ƥޤ  "

#define BLOCK_TEST_1 "ƻ˶ιܤޤޤޤ "
#define BLOCK_TEST_2 "ƻΥǡ礭 "
#define BLOCK_TEST_3 "ƻΥǥߥο "
#define BLOCK_TEST_4 "ƻƬब'#'Ǥ롢̾盧߾֤Ǥ "
#define BLOCK_TEST_5 " "
#define BLOCK_TEST_6 "۾ "
#define BLOCK_TEST_7 "ƻ˲餫꤬褦Ǥ "

#define ERR_MAIL_1 "Ļδְ㤤 "
#define ERR_MAIL_2 "Υ֥å˳Ƥ줿Ļ֤äƤޤ "
#define ERR_MAIL_3 "Ļܤ¿١ιԤĻ뤵Ƥޤ "



#endif
